@@ -229,7 +229,7 @@ class ArgumentSpec:
     defaults: Any
     types: Any
 
-    __robot_arguments: Optional[Any] = None
+    __robot_arguments: Optional[Any] = field(default=None, compare=False)
 
     @staticmethod
     def from_robot_argument_spec(spec: Any) -> ArgumentSpec:
@@ -294,6 +294,7 @@ class KeywordDoc:
     end_line_no: int = -1
     type: str = "keyword"
     libname: Optional[str] = None
+    libtype: Optional[str] = None
     longname: Optional[str] = None
     is_embedded: bool = False
     errors: Optional[List[Error]] = None
@@ -313,6 +314,14 @@ class KeywordDoc:
     def is_deprecated(self) -> bool:
         return self.deprecated or DEPRECATED_PATTERN.match(self.doc) is not None
 
+    @property
+    def is_resource_keyword(self) -> bool:
+        return self.libtype == "RESOURCE"
+
+    @property
+    def is_library_keyword(self) -> bool:
+        return self.libtype == "LIBRARY"
+
     @property
     def deprecated_message(self) -> str:
         if (m := DEPRECATED_PATTERN.match(self.doc)) is not None:
@@ -470,6 +479,9 @@ class KeywordStore:
         except KeyError:
             return default
 
+    def get_all(self, key: str) -> List[KeywordDoc]:
+        return [v for k, v in self._matchers.items() if k == key]
+
 
 @dataclass
 class ModuleSpec:
@@ -1218,6 +1230,7 @@ def get_library_doc(
                             # libname=kw[1].libname,
                             # longname=kw[1].longname,
                             libname=libdoc.name,
+                            libtype=libdoc.type,
                             longname=f"{libdoc.name}.{kw[0].name}",
                             doc_format=str(lib.doc_format) or DEFAULT_DOC_FORMAT,
                             is_initializer=True,
@@ -1255,6 +1268,7 @@ def get_library_doc(
                             source=kw[0].source,
                             line_no=kw[0].lineno,
                             libname=libdoc.name,
+                            libtype=libdoc.type,
                             longname=f"{libdoc.name}.{kw[0].name}",
                             is_embedded=is_embedded_keyword(kw[0].name),
                             doc_format=str(lib.doc_format) or DEFAULT_DOC_FORMAT,
