@@ -217,16 +217,20 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
                     if context.include_declaration and variable.source
                     else []
                 ),
-                *(await self.find_variable_references(document, variable)),
+                *(await self.find_variable_references(document, variable, context.include_declaration)),
             ]
 
         return None
 
-    async def find_variable_references(self, document: TextDocument, variable: VariableDefinition) -> List[Location]:
+    async def find_variable_references(
+        self, document: TextDocument, variable: VariableDefinition, include_declaration: bool = True
+    ) -> List[Location]:
         return (
-            await create_sub_task(self.find_variable_references_in_file(document, variable))
+            await create_sub_task(self.find_variable_references_in_file(document, variable, include_declaration))
             if isinstance(variable, (ArgumentDefinition, LocalVariableDefinition))
-            else await self._find_references(document, self.find_variable_references_in_file, variable)
+            else await self._find_references(
+                document, self.find_variable_references_in_file, variable, include_declaration
+            )
         )
 
     async def yield_argument_name_and_rest(self, node: ast.AST, token: Token) -> AsyncGenerator[Token, None]:
@@ -260,9 +264,7 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
 
     @_logger.call
     async def find_variable_references_in_file(
-        self,
-        doc: TextDocument,
-        variable: VariableDefinition,
+        self, doc: TextDocument, variable: VariableDefinition, include_declaration: bool = True
     ) -> List[Location]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.blocks import Block, Keyword, Section, TestCase
@@ -309,7 +311,14 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
                             sub_token, found_variable = token_and_var
 
                             if found_variable == variable:
-                                result.append(Location(str(doc.uri), range_from_token(sub_token)))
+                                if (
+                                    include_declaration
+                                    or found_variable.name_token is None
+                                    or not include_declaration
+                                    and variable.name_token is not None
+                                    and range_from_token(variable.name_token) != range_from_token(sub_token)
+                                ):
+                                    result.append(Location(str(doc.uri), range_from_token(sub_token)))
 
             if (
                 isinstance(node, Statement)
@@ -348,25 +357,10 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
 
         doc = await namespace.get_library_doc()
         if doc is not None:
-            keyword = next(
-                (v for v in doc.keywords.keywords if v.name == name_token.value and v.line_no == kw_node.lineno),
-                None,
-            )
+            keyword = await self.get_keyword_definition_at_token(namespace, name_token)
 
             if keyword is not None and keyword.source and not keyword.is_error_handler:
-                return [
-                    *(
-                        [
-                            Location(
-                                uri=str(Uri.from_path(keyword.source)),
-                                range=keyword.range,
-                            )
-                        ]
-                        if context.include_declaration and keyword.source
-                        else []
-                    ),
-                    *await self.find_keyword_references(document, keyword),
-                ]
+                return await self.find_keyword_references(document, keyword, context.include_declaration)
 
         return None
 
@@ -407,14 +401,7 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
                     return None
 
             if position in kw_range and keyword_doc is not None:
-                return [
-                    *(
-                        [Location(uri=str(Uri.from_path(keyword_doc.source)), range=keyword_doc.range)]
-                        if context.include_declaration and keyword_doc.source
-                        else []
-                    ),
-                    *await self.find_keyword_references(document, keyword_doc),
-                ]
+                return await self.find_keyword_references(document, keyword_doc, context.include_declaration)
 
         return None
 
@@ -460,14 +447,7 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
                     return None
 
             if position in kw_range and keyword_doc is not None and not keyword_doc.is_error_handler:
-                return [
-                    *(
-                        [Location(uri=str(Uri.from_path(keyword_doc.source)), range=keyword_doc.range)]
-                        if context.include_declaration and keyword_doc.source
-                        else []
-                    ),
-                    *await self.find_keyword_references(document, keyword_doc),
-                ]
+                return await self.find_keyword_references(document, keyword_doc, context.include_declaration)
 
         return None
 
@@ -506,20 +486,9 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
                         if position in r:
                             # TODO: find references for Library Namespace
                             return None
+
                     if keyword_doc:
-                        return [
-                            *(
-                                [
-                                    Location(
-                                        uri=str(Uri.from_path(keyword_doc.source)),
-                                        range=keyword_doc.range,
-                                    )
-                                ]
-                                if context.include_declaration and keyword_doc.source
-                                else []
-                            ),
-                            *await self.find_keyword_references(document, keyword_doc),
-                        ]
+                        return await self.find_keyword_references(document, keyword_doc, context.include_declaration)
 
         return None
 
@@ -539,6 +508,7 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
         doc: TextDocument,
         kw_doc: KeywordDoc,
         lib_doc: Optional[LibraryDoc] = None,
+        include_declaration: bool = True,
     ) -> List[Location]:
 
         try:
@@ -553,7 +523,7 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
             ):
                 return []
 
-            return await self._find_keyword_references_in_namespace(namespace, kw_doc)
+            return await self._find_keyword_references_in_namespace(namespace, kw_doc, include_declaration)
         except (SystemExit, KeyboardInterrupt, asyncio.CancelledError):
             raise
         except BaseException as e:
@@ -561,11 +531,14 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
 
         return []
 
-    async def _find_keyword_references_in_namespace(self, namespace: Namespace, kw_doc: KeywordDoc) -> List[Location]:
+    async def _find_keyword_references_in_namespace(
+        self, namespace: Namespace, kw_doc: KeywordDoc, include_declaration: bool = True
+    ) -> List[Location]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import (
             Fixture,
             KeywordCall,
+            KeywordName,
             Template,
             TestTemplate,
         )
@@ -598,6 +571,18 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
 
                 async for location in self.get_keyword_references_from_tokens(namespace, kw_doc, node, kw_token, []):
                     result.append(location)
+            elif include_declaration and isinstance(node, KeywordName):
+                kw_token = node.get_token(RobotToken.KEYWORD_NAME)
+                if kw_token:
+                    kw = await self.get_keyword_definition_at_token(namespace, kw_token)
+
+                    if kw is not None and kw == kw_doc:
+                        result.append(
+                            Location(
+                                str(Uri.from_path(namespace.source).normalized()),
+                                range=range_from_token(kw_token),
+                            )
+                        )
 
         return result
 
@@ -728,7 +713,9 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
                     async for e in self.get_keyword_references_from_tokens(namespace, kw_doc, node, t, args, True):
                         yield e
 
-    async def find_keyword_references(self, document: TextDocument, kw_doc: KeywordDoc) -> List[Location]:
+    async def find_keyword_references(
+        self, document: TextDocument, kw_doc: KeywordDoc, include_declaration: bool = True
+    ) -> List[Location]:
         folder = self.parent.workspace.get_workspace_folder(document.uri)
         if folder is None:
             return []
@@ -757,7 +744,16 @@ class RobotReferencesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMi
             or await namespace.get_library_doc()
         )
 
-        return await self._find_references(document, self.find_keyword_references_in_file, kw_doc, lib_doc)
+        return [
+            *(
+                [Location(str(Uri.from_path(kw_doc.source)), kw_doc.range)]
+                if include_declaration and kw_doc.libtype == "LIBRARY" and kw_doc.source
+                else []
+            ),
+            *await self._find_references(
+                document, self.find_keyword_references_in_file, kw_doc, lib_doc, include_declaration
+            ),
+        ]
 
     @_logger.call
     async def _find_library_import_references_in_file(
