@@ -123,7 +123,7 @@ class RobotRoboCopDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
 
             # TODO find a way to cancel the run_check
             issues = await analyser.run_check(  # type: ignore
-                await self.parent.documents_cache.get_model(document),
+                await self.parent.documents_cache.get_model(document, False),
                 str(document.uri.to_path()),
                 await document.text(),
             )
